items property
A list of SequenceEntrys to animate, usually an instance of either SequenceItem or SequenceGroup.
It's recommended to use AnimatedVectorDatas in this sequence that have the same viewport aspect ratio to avoid stretched animations.
Implementation
final List<SequenceEntry> items;